@@ -1,23 +1,21 @@
 # MathML::Entitities
 #
-# Copyright, Jacques Distler 2005-2025.
+# Copyright, Jacques Distler 2005.
 # All Rights Reserved.
 # Licensed under the Perl Artistic License.
 #
-# Version: 0.19.1
+# Version: 0.11
 
 package MathML::Entities;
 
-use 5.006;
 use strict;
-use warnings;
 require Exporter;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw( name2numbered name2utf8 );
-our $VERSION = '0.19.1';
+our $VERSION = '0.11';
 
-our %ENTITIES = (
+my %ENTITIES = (
 	'Alpha' => '&#x0391;',
 	'Beta' => '&#x0392;',
 	'Epsilon' => '&#x0395;',
@@ -42,6 +40,7 @@ our %ENTITIES = (
 	'alefsym' => '&#x2135;',
 	'crarr' => '&#x21B5;',
 	'empty' => '&#x2205;',
+	'hearts' => '&#x2265;',
 	'amp' => '&#x0026;',
 	'lt' => '&#x003C;',
 	'zwnj' => '&#x200C;',
@@ -274,7 +273,7 @@ our %ENTITIES = (
 	'plussim' => '&#x02A26;',
 	'plustwo' => '&#x02A27;',
 	'prod' => '&#x0220F;',
-	'race' => '&#x0223D;&#x0331;',
+	'race' => '&#x029DA;',
 	'roplus' => '&#x02A2E;',
 	'rotimes' => '&#x02A35;',
 	'rthree' => '&#x022CC;',
@@ -462,7 +461,7 @@ our %ENTITIES = (
 	'iiota' => '&#x02129;',
 	'image' => '&#x02111;',
 	'imath' => '&#x00131;',
-	'jmath' => '&#x00237;',
+	'jmath' => '&#x0006A;',
 	'laemptyv' => '&#x029B4;',
 	'lltri' => '&#x025FA;',
 	'lrtri' => '&#x022BF;',
@@ -476,7 +475,7 @@ our %ENTITIES = (
 	'range' => '&#x029A5;',
 	'real' => '&#x0211C;',
 	'tbrk' => '&#x023B4;',
-	'trpezium' => '&#x023E2;',
+	'trpezium' => '&#x0FFFD;',
 	'ultri' => '&#x025F8;',
 	'urtri' => '&#x025F9;',
 	'vzigzag' => '&#x0299A;',
@@ -491,7 +490,7 @@ our %ENTITIES = (
 	'bowtie' => '&#x022C8;',
 	'bsim' => '&#x0223D;',
 	'bsime' => '&#x022CD;',
-	'bsolhsub' => '&#x27C8;',
+	'bsolhsub' => '&#x0005C;&#x02282;',
 	'bump' => '&#x0224E;',
 	'bumpE' => '&#x02AAE;',
 	'bumpe' => '&#x0224F;',
@@ -636,7 +635,7 @@ our %ENTITIES = (
 	'supdsub' => '&#x02AD8;',
 	'supE' => '&#x02AC6;',
 	'supedot' => '&#x02AC4;',
-	'suphsol' => '&#x027C9;',
+	'suphsol' => '&#x02283;&#x0002F;',
 	'suphsub' => '&#x02AD7;',
 	'suplarr' => '&#x0297B;',
 	'supmult' => '&#x02AC2;',
@@ -667,7 +666,7 @@ our %ENTITIES = (
 	'Delta' => '&#x00394;',
 	'delta' => '&#x003B4;',
 	'epsi' => '&#x003F5;',
-	'epsiv' => '&#x003F5;',
+	'epsiv' => '&#x003B5;',
 	'eta' => '&#x003B7;',
 	'Gamma' => '&#x00393;',
 	'gamma' => '&#x003B3;',
@@ -682,11 +681,9 @@ our %ENTITIES = (
 	'nu' => '&#x003BD;',
 	'Omega' => '&#x003A9;',
 	'omega' => '&#x003C9;',
-	'phgr' => '&#x003C6;',
 	'Phi' => '&#x003A6;',
-	'phi' => '&#x003C6;',
-	'phis' => '&#x003D5;',
-	'phiv' => '&#x003D5;',
+	'phi' => '&#x003D5;',
+	'phiv' => '&#x003C6;',
 	'Pi' => '&#x003A0;',
 	'pi' => '&#x003C0;',
 	'piv' => '&#x003D6;',
@@ -846,7 +843,7 @@ our %ENTITIES = (
 	'andv' => '&#x02A5A;',
 	'angrt' => '&#x0221F;',
 	'angsph' => '&#x02222;',
-	'angst' => '&#x000C5;',
+	'angst' => '&#x0212B;',
 	'ap' => '&#x02248;',
 	'apacir' => '&#x02A6F;',
 	'awconint' => '&#x02233;',
@@ -876,7 +873,7 @@ our %ENTITIES = (
 	'dsol' => '&#x029F6;',
 	'dtdot' => '&#x022F1;',
 	'dwangle' => '&#x029A6;',
-	'elinters' => '&#x023E7;',
+	'elinters' => '&#x0FFFD;',
 	'epar' => '&#x022D5;',
 	'eparsl' => '&#x029E3;',
 	'equiv' => '&#x02261;',
@@ -903,13 +900,13 @@ our %ENTITIES = (
 	'isinsv' => '&#x022F3;',
 	'isinv' => '&#x02208;',
 	'lagran' => '&#x02112;',
-	'Lang' => '&#x027EA;',
-	'lang' => '&#x027E8;',
+	'Lang' => '&#x0300A;',
+	'lang' => '&#x02329;',
 	'lArr' => '&#x021D0;',
-	'lbbrk' => '&#x02772;',
+	'lbbrk' => '&#x03014;',
 	'le' => '&#x02264;',
-	'loang' => '&#x027EC;',
-	'lobrk' => '&#x027E6;',
+	'loang' => '&#x03018;',
+	'lobrk' => '&#x0301A;',
 	'lopar' => '&#x02985;',
 	'lowast' => '&#x02217;',
 	'minus' => '&#x02212;',
@@ -963,12 +960,12 @@ our %ENTITIES = (
 	'qprime' => '&#x02057;',
 	'quatint' => '&#x02A16;',
 	'radic' => '&#x0221A;',
-	'Rang' => '&#x027EB;',
-	'rang' => '&#x027E9;',
+	'Rang' => '&#x0300B;',
+	'rang' => '&#x0232A;',
 	'rArr' => '&#x021D2;',
-	'rbbrk' => '&#x02773;',
-	'roang' => '&#x027ED;',
-	'robrk' => '&#x027E7;',
+	'rbbrk' => '&#x03015;',
+	'roang' => '&#x03019;',
+	'robrk' => '&#x0301B;',
 	'ropar' => '&#x02986;',
 	'rppolint' => '&#x02A12;',
 	'scpolint' => '&#x02A13;',
@@ -1369,7 +1366,7 @@ our %ENTITIES = (
 	'nbsp' => '&#x000A0;',
 	'not' => '&#x000AC;',
 	'num' => '&#x00023;',
-	'ohm' => '&#x03A9;',
+	'ohm' => '&#x02126;',
 	'ordf' => '&#x000AA;',
 	'ordm' => '&#x000BA;',
 	'para' => '&#x000B6;',
@@ -1430,7 +1427,6 @@ our %ENTITIES = (
 	'fflig' => '&#x0FB00;',
 	'ffllig' => '&#x0FB04;',
 	'filig' => '&#x0FB01;',
-	'fjlig' => '&#x00066;&#x0006A;',
 	'flat' => '&#x0266D;',
 	'fllig' => '&#x0FB02;',
 	'frac13' => '&#x02153;',
@@ -1554,10 +1550,10 @@ our %ENTITIES = (
 	'NotSquareSuperset' => '&#x02290;&#x00338;',
 	'NotSucceedsTilde' => '&#x0227F;&#x00338;',
 	'oopf' => '&#x1D560;',
-	'OverBar' => '&#x0203E;',
-	'OverBrace' => '&#x023DE;',
+	'OverBar' => '&#x000AF;',
+	'OverBrace' => '&#x0FE37;',
 	'OverBracket' => '&#x023B4;',
-	'OverParenthesis' => '&#x023DC;',
+	'OverParenthesis' => '&#x0FE35;',
 	'planckh' => '&#x0210E;',
 	'popf' => '&#x1D561;',
 	'Product' => '&#x0220F;',
@@ -1576,12 +1572,12 @@ our %ENTITIES = (
 	'RuleDelayed' => '&#x029F4;',
 	'sopf' => '&#x1D564;',
 	'Tab' => '&#x00009;',
-	'ThickSpace' => '&#x0205F;&#x0200A;',
+	'ThickSpace' => '&#x02009;&#x0200A;&#x0200A;',
 	'topf' => '&#x1D565;',
-	'UnderBar' => '&#x0005F;',
-	'UnderBrace' => '&#x023DF;',
+	'UnderBar' => '&#x00332;',
+	'UnderBrace' => '&#x0FE38;',
 	'UnderBracket' => '&#x023B5;',
-	'UnderParenthesis' => '&#x023DD;',
+	'UnderParenthesis' => '&#x0FE36;',
 	'uopf' => '&#x1D566;',
 	'UpArrowBar' => '&#x02912;',
 	'Upsilon' => '&#x003A5;',
@@ -1785,11 +1781,11 @@ our %ENTITIES = (
 	'intprod' => '&#x02A3C;',
 	'InvisibleComma' => '&#x02063;',
 	'InvisibleTimes' => '&#x02062;',
-	'langle' => '&#x027E8;',
+	'langle' => '&#x02329;',
 	'Laplacetrf' => '&#x02112;',
 	'lbrace' => '&#x0007B;',
 	'lbrack' => '&#x0005B;',
-	'LeftAngleBracket' => '&#x027E8;',
+	'LeftAngleBracket' => '&#x02329;',
 	'LeftArrow' => '&#x02190;',
 	'Leftarrow' => '&#x021D0;',
 	'leftarrow' => '&#x02190;',
@@ -1797,7 +1793,7 @@ our %ENTITIES = (
 	'LeftArrowRightArrow' => '&#x021C6;',
 	'leftarrowtail' => '&#x021A2;',
 	'LeftCeiling' => '&#x02308;',
-	'LeftDoubleBracket' => '&#x027E6;',
+	'LeftDoubleBracket' => '&#x0301A;',
 	'LeftDownVector' => '&#x021C3;',
 	'LeftFloor' => '&#x0230A;',
 	'leftharpoondown' => '&#x021BD;',
@@ -1894,7 +1890,7 @@ our %ENTITIES = (
 	'NotExists' => '&#x02204;',
 	'NotGreater' => '&#x0226F;',
 	'NotGreaterEqual' => '&#x02271;',
-	'NotGreaterFullEqual' => '&#x02267;&#x00338;',
+	'NotGreaterFullEqual' => '&#x02266;&#x00338;',
 	'NotGreaterGreater' => '&#x0226B;&#x00338;',
 	'NotGreaterLess' => '&#x02279;',
 	'NotGreaterSlantEqual' => '&#x02A7E;&#x00338;',
@@ -1977,7 +1973,7 @@ our %ENTITIES = (
 	'propto' => '&#x0221D;',
 	'quaternions' => '&#x0210D;',
 	'questeq' => '&#x0225F;',
-	'rangle' => '&#x027E9;',
+	'rangle' => '&#x0232A;',
 	'rationals' => '&#x0211A;',
 	'rbrace' => '&#x0007D;',
 	'rbrack' => '&#x0005D;',
@@ -1988,7 +1984,7 @@ our %ENTITIES = (
 	'ReverseElement' => '&#x0220B;',
 	'ReverseEquilibrium' => '&#x021CB;',
 	'ReverseUpEquilibrium' => '&#x0296F;',
-	'RightAngleBracket' => '&#x027E9;',
+	'RightAngleBracket' => '&#x0232A;',
 	'RightArrow' => '&#x02192;',
 	'Rightarrow' => '&#x021D2;',
 	'rightarrow' => '&#x02192;',
@@ -1996,7 +1992,7 @@ our %ENTITIES = (
 	'RightArrowLeftArrow' => '&#x021C4;',
 	'rightarrowtail' => '&#x021A3;',
 	'RightCeiling' => '&#x02309;',
-	'RightDoubleBracket' => '&#x027E7;',
+	'RightDoubleBracket' => '&#x0301B;',
 	'RightDownVector' => '&#x021C2;',
 	'RightFloor' => '&#x0230B;',
 	'rightharpoondown' => '&#x021C1;',
@@ -2114,10 +2110,10 @@ our %ENTITIES = (
 	'UpTeeArrow' => '&#x021A5;',
 	'upuparrows' => '&#x021C8;',
 	'urcorner' => '&#x0231D;',
-	'varepsilon' => '&#x003F5;',
+	'varepsilon' => '&#x003B5;',
 	'varkappa' => '&#x003F0;',
 	'varnothing' => '&#x02205;',
-	'varphi' => '&#x003D5;',
+	'varphi' => '&#x003C6;',
 	'varpi' => '&#x003D6;',
 	'varpropto' => '&#x0221D;',
 	'varrho' => '&#x003F1;',
@@ -2140,25 +2136,18 @@ our %ENTITIES = (
 	'wedge' => '&#x02227;',
 	'wp' => '&#x02118;',
 	'wr' => '&#x02240;',
-	'zeetrf' => '&#x02128;',
-	'AMP' => '&#x0026',
-	'COPY' => '&#x00A9',
-	'GT' => '&#x003E',
-	'LT' => '&#x003C',
-	'QUOT' => '&#x0022',
-	'REG' => '&#x00AE',
-	'TRADE' => '&#x2122'
+	'zeetrf' => '&#x02128;'
 );
 
 sub name2numbered {
     my $content = shift;
-    $content =~ s/(&(?:(lt|gt|amp|quot|apos)|[a-zA-Z0-9]+);)/$2 ? lc($1) : _convert2numbered($1)/eig;
+    $content =~ s/(&(?:(lt|gt|amp|quot|apos)|[a-zA-Z0-9]+);)/$2 ? $1 : _convert2numbered($1)/eg;
     return $content;
 }
 
 sub name2utf8 {
     my $content = shift;
-    $content =~ s/(&(?:(lt|gt|amp|quot|apos)|[a-zA-Z0-9]+);)/$2 ? lc($1) : _convert2utf8($1)/eig;
+    $content =~ s/(&(?:(lt|gt|amp|quot|apos)|[a-zA-Z0-9]+);)/$2 ? $1 : _convert2utf8($1)/eg;
     return $content;
 }
 
@@ -2244,15 +2233,13 @@ XHTML+MathML named entities (except for the five "safe" XML named entities)
 in the argument of C<name2utf8()> are replaced by the corresponding
 utf-8 characters.
 
-=back
-
 =head1 AUTHOR
 
 Jacques Distler E<lt>distler@golem.ph.utexas.eduE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2025 Jacques Distler. All rights reserved.
+Copyright (c) 2005 Jacques Distler. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
